=== modified file 'olive/commit.py'
--- olive/commit.py	2006-09-27 17:29:17 +0000
+++ olive/commit.py	2006-09-27 17:38:39 +0000
@@ -34,9 +34,11 @@
 import bzrlib.errors as errors
 from bzrlib.workingtree import WorkingTree
 
+from dialog import error_dialog
+
 class OliveCommit:
     """ Display Commit dialog and perform the needed actions. """
-    def __init__(self, gladefile, wt, wtpath, dialog):
+    def __init__(self, gladefile, wt, wtpath):
         """ Initialize the Commit dialog. """
         self.gladefile = gladefile
         self.glade = gtk.glade.XML(self.gladefile, 'window_commit', 'olive-gtk')
@@ -44,9 +46,6 @@
         self.wt = wt
         self.wtpath = wtpath
 
-        # Dialog object
-        self.dialog = dialog
-        
         # Get some important widgets
         self.window = self.glade.get_widget('window_commit')
         self.checkbutton_local = self.glade.get_widget('checkbutton_commit_local')
@@ -80,7 +79,7 @@
     def display(self):
         """ Display the Push dialog. """
         if self.notbranch:
-            self.dialog.error_dialog(_('Directory is not a branch'),
+            error_dialog(_('Directory is not a branch'),
                                      _('You can perform this action only in a branch.'))
             self.close()
         else:
@@ -151,31 +150,31 @@
                            local=self.checkbutton_local.get_active(),
                            specific_files=specific_files)
         except errors.NotBranchError:
-            self.dialog.error_dialog(_('Directory is not a branch'),
+            error_dialog(_('Directory is not a branch'),
                                      _('You can perform this action only in a branch.'))
             return
         except errors.LocalRequiresBoundBranch:
-            self.dialog.error_dialog(_('Directory is not a checkout'),
+            error_dialog(_('Directory is not a checkout'),
                                      _('You can perform local commit only on checkouts.'))
             return
         except errors.PointlessCommit:
-            self.dialog.error_dialog(_('No changes to commit'),
+            error_dialog(_('No changes to commit'),
                                      _('Try force commit if you want to commit anyway.'))
             return
         except errors.ConflictsInTree:
-            self.dialog.error_dialog(_('Conflicts in tree'),
+            error_dialog(_('Conflicts in tree'),
                                      _('You need to resolve the conflicts before committing.'))
             return
         except errors.StrictCommitFailed:
-            self.dialog.error_dialog(_('Strict commit failed'),
+            error_dialog(_('Strict commit failed'),
                                      _('There are unknown files in the working tree.\nPlease add or delete them.'))
             return
         except errors.BoundBranchOutOfDate, errmsg:
-            self.dialog.error_dialog(_('Bound branch is out of date'),
+            error_dialog(_('Bound branch is out of date'),
                                      _('%s') % errmsg)
             return
         except errors.BzrError, msg:
-            self.dialog.error_dialog(_('Unknown error'), str(msg))
+            error_dialog(_('Unknown error'), str(msg))
             return
         
         self.close()

=== modified file 'olive/dialog.py'
--- olive/dialog.py	2006-09-13 20:19:31 +0000
+++ olive/dialog.py	2006-09-27 17:38:39 +0000
@@ -27,63 +27,59 @@
 except:
     sys.exit(1)
 
-class OliveDialog:
-    def __init__(self, gladefile):
-        self.gladefile = gladefile
-        
-    def about(self):
-        """ Display the AboutDialog. """
-        import olive
-
-        # Load AboutDialog description
-        dglade = gtk.glade.XML(self.gladefile, 'aboutdialog')
-        dialog = dglade.get_widget('aboutdialog')
-
-        # Set version
-        dialog.set_version(olive.__version__)
-        
-        # Destroy the dialog
-        if dialog.run() == gtk.RESPONSE_CANCEL:
-            dialog.destroy()
-    
-    def _message_dialog(self, type, primary, secondary):
-        """ Display a given type of MessageDialog with the given message.
-        
-        :param type: error | warning | info
-        
-        :param message: the message you want to display.
-        """
-        if type == 'error':
-            dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
-                                       type=gtk.MESSAGE_ERROR,
-                                       buttons=gtk.BUTTONS_OK)
-            dialog.set_markup('<big><b>' + primary + '</b></big>')
-        elif type == 'warning':
-            dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
-                                       type=gtk.MESSAGE_WARNING,
-                                       buttons=gtk.BUTTONS_OK)
-            dialog.set_markup('<big><b>' + primary + '</b></big>')
-        elif type == 'info':
-            dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
-                                       type=gtk.MESSAGE_INFO,
-                                       buttons=gtk.BUTTONS_OK)
-            dialog.set_markup('<big><b>' + primary + '</b></big>')
-        else:
-            return
-        
-        dialog.format_secondary_markup(secondary)
-        
-        if dialog.run() == gtk.RESPONSE_OK:
-            dialog.destroy()
-    
-    def error_dialog(self, primary, secondary):
-        """ Display an error dialog with the given message. """
-        self._message_dialog('error', primary, secondary)
-    
-    def info_dialog(self, primary, secondary):
-        """ Display an info dialog with the given message. """
-        self._message_dialog('info', primary, secondary)
-    
-    def warning_dialog(self, primary, secondary):
-        """ Display a warning dialog with the given message. """
-        self._message_dialog('warning', primary, secondary)
+def about():
+	""" Display the AboutDialog. """
+	import olive
+
+	# Load AboutDialog description
+	dglade = gtk.glade.XML(gladefile, 'aboutdialog')
+	dialog = dglade.get_widget('aboutdialog')
+
+	# Set version
+	dialog.set_version(olive.__version__)
+	
+	# Destroy the dialog
+	if dialog.run() == gtk.RESPONSE_CANCEL:
+		dialog.destroy()
+
+def _message_dialog(type, primary, secondary):
+	""" Display a given type of MessageDialog with the given message.
+	
+	:param type: error | warning | info
+	
+	:param message: the message you want to display.
+	"""
+	if type == 'error':
+		dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
+								   type=gtk.MESSAGE_ERROR,
+								   buttons=gtk.BUTTONS_OK)
+		dialog.set_markup('<big><b>' + primary + '</b></big>')
+	elif type == 'warning':
+		dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
+								   type=gtk.MESSAGE_WARNING,
+								   buttons=gtk.BUTTONS_OK)
+		dialog.set_markup('<big><b>' + primary + '</b></big>')
+	elif type == 'info':
+		dialog = gtk.MessageDialog(flags=gtk.DIALOG_MODAL,
+								   type=gtk.MESSAGE_INFO,
+								   buttons=gtk.BUTTONS_OK)
+		dialog.set_markup('<big><b>' + primary + '</b></big>')
+	else:
+		return
+	
+	dialog.format_secondary_markup(secondary)
+	
+	if dialog.run() == gtk.RESPONSE_OK:
+		dialog.destroy()
+
+def error_dialog(primary, secondary):
+	""" Display an error dialog with the given message. """
+	_message_dialog('error', primary, secondary)
+
+def info_dialog(primary, secondary):
+	""" Display an info dialog with the given message. """
+	_message_dialog('info', primary, secondary)
+
+def warning_dialog(primary, secondary):
+	""" Display a warning dialog with the given message. """
+	_message_dialog('warning', primary, secondary)

=== modified file 'olive/handler.py'
--- olive/handler.py	2006-09-27 17:25:14 +0000
+++ olive/handler.py	2006-09-27 17:38:39 +0000
@@ -32,7 +32,7 @@
 from bzrlib.branch import Branch
 from bzrlib.workingtree import WorkingTree
 
-from dialog import OliveDialog
+from dialog import about, error_dialog, info_dialog
 from menu import OliveMenu
 from launch import launch
 
@@ -42,36 +42,34 @@
         self.gladefile = gladefile
         self.comm = comm
         
-        self.dialog = OliveDialog(self.gladefile)
-        
-        self.menu = OliveMenu(self.gladefile, self.comm, self.dialog)
+        self.menu = OliveMenu(self.gladefile, self.comm)
     
     def on_about_activate(self, widget):
-        self.dialog.about()
+        about()
         
     def on_menuitem_add_files_activate(self, widget):
         """ Add file(s)... menu handler. """
         from add import OliveAdd
-        add = OliveAdd(self.gladefile, self.comm, self.dialog)
+        add = OliveAdd(self.gladefile, self.comm)
         add.display()
     
     def on_menuitem_branch_get_activate(self, widget):
         """ Branch/Get... menu handler. """
         from branch import OliveBranch
-        branch = OliveBranch(self.gladefile, self.comm, self.dialog)
+        branch = OliveBranch(self.gladefile, self.comm)
         branch.display()
     
     def on_menuitem_branch_checkout_activate(self, widget):
         """ Branch/Checkout... menu handler. """
         from checkout import OliveCheckout
-        checkout = OliveCheckout(self.gladefile, self.comm, self.dialog)
+        checkout = OliveCheckout(self.gladefile, self.comm)
         checkout.display()
     
     def on_menuitem_branch_commit_activate(self, widget):
         """ Branch/Commit... menu handler. """
         from commit import OliveCommit
         wt, path = WorkingTree.open_containing(self.comm.get_path())
-        commit = OliveCommit(self.gladefile, wt, path, self.dialog)
+        commit = OliveCommit(self.gladefile, wt, path)
         commit.display()
     
     def on_menuitem_branch_missing_revisions_activate(self, widget):
@@ -85,13 +83,13 @@
             try:
                 local_branch = Branch.open_containing(self.comm.get_path())[0]
             except NotBranchError:
-                self.dialog.error_dialog(_('Directory is not a branch'),
+                error_dialog(_('Directory is not a branch'),
                                          _('You can perform this action only in a branch.'))
                 return
             
             other_branch = local_branch.get_parent()
             if other_branch is None:
-                self.dialog.error_dialog(_('Parent location is unknown'),
+                error_dialog(_('Parent location is unknown'),
                                          _('Cannot determine missing revisions if no parent location is known.'))
                 return
             
@@ -103,10 +101,10 @@
             ret = len(local_branch.missing_revisions(remote_branch))
 
             if ret > 0:
-                self.dialog.info_dialog(_('There are missing revisions'),
+                info_dialog(_('There are missing revisions'),
                                         _('%d revision(s) missing.') % ret)
             else:
-                self.dialog.info_dialog(_('Local branch up to date'),
+                info_dialog(_('Local branch up to date'),
                                         _('There are no missing revisions.'))
         finally:
             self.comm.set_busy(self.comm.window_main, False)
@@ -125,19 +123,19 @@
                 tree_to = None
                 branch_to = Branch.open_containing(self.comm.get_path())[0]
             except errors.NotBranchError:
-                 self.dialog.error_dialog(_('Directory is not a branch'),
+                 error_dialog(_('Directory is not a branch'),
                                          _('You can perform this action only in a branch.'))
 
             location = branch_to.get_parent()
             if location is None:
-                self.dialog.error_dialog(_('Parent location is unknown'),
+                error_dialog(_('Parent location is unknown'),
                                          _('Pulling is not possible until there is a parent location.'))
                 return
 
             try:
                 branch_from = Branch.open(location)
             except errors.NotBranchError:
-                self.dialog.error_dialog(_('Directory is not a branch'),
+                error_dialog(_('Directory is not a branch'),
                                          _('You can perform this action only in a branch.'))
 
             if branch_to.get_parent() is None:
@@ -149,7 +147,7 @@
             else:
                 branch_to.pull(branch_from)
             
-            self.dialog.info_dialog(_('Pull successful'),
+            info_dialog(_('Pull successful'),
                                     _('%d revision(s) pulled.') % ret)
             
         finally:
@@ -158,14 +156,14 @@
     def on_menuitem_branch_push_activate(self, widget):
         """ Branch/Push... menu handler. """
         from push import OlivePush
-        push = OlivePush(self.gladefile, self.comm, self.dialog)
+        push = OlivePush(self.gladefile, self.comm)
         push.display()
     
     def on_menuitem_branch_status_activate(self, widget):
         """ Branch/Status... menu handler. """
         from status import OliveStatus
         wt, wtpath = WorkingTree.open_containing(self.comm.get_path())
-        status = OliveStatus(self.gladefile, wt, wtpath, self.dialog)
+        status = OliveStatus(self.gladefile, wt, wtpath)
         status.display()
     
     def on_menuitem_branch_initialize_activate(self, widget):
@@ -193,56 +191,56 @@
                     existing_bzrdir.create_branch()
                     existing_bzrdir.create_workingtree()
         except errors.AlreadyBranchError, errmsg:
-            self.dialog.error_dialog(_('Directory is already a branch'),
+            error_dialog(_('Directory is already a branch'),
                                      _('The current directory (%s) is already a branch.\nYou can start using it, or initialize another directory.') % errmsg)
         except errors.BranchExistsWithoutWorkingTree, errmsg:
-            self.dialog.error_dialog(_('Branch without a working tree'),
+            error_dialog(_('Branch without a working tree'),
                                      _('The current directory (%s)\nis a branch without a working tree.') % errmsg)
         else:
-            self.dialog.info_dialog(_('Initialize successful'),
+            info_dialog(_('Initialize successful'),
                                     _('Directory successfully initialized.'))
             self.comm.refresh_right()
         
     def on_menuitem_file_make_directory_activate(self, widget):
         """ File/Make directory... menu handler. """
         from mkdir import OliveMkdir
-        mkdir = OliveMkdir(self.gladefile, self.comm, self.dialog)
+        mkdir = OliveMkdir(self.gladefile, self.comm)
         mkdir.display()
     
     def on_menuitem_file_move_activate(self, widget):
         """ File/Move... menu handler. """
         from move import OliveMove
-        move = OliveMove(self.gladefile, self.comm, self.dialog)
+        move = OliveMove(self.gladefile, self.comm)
         move.display()
     
     def on_menuitem_file_rename_activate(self, widget):
         """ File/Rename... menu handler. """
         from rename import OliveRename
-        rename = OliveRename(self.gladefile, self.comm, self.dialog)
+        rename = OliveRename(self.gladefile, self.comm)
         rename.display()
 
     def on_menuitem_remove_file_activate(self, widget):
         """ Remove (unversion) selected file. """
         from remove import OliveRemove
-        remove = OliveRemove(self.gladefile, self.comm, self.dialog)
+        remove = OliveRemove(self.gladefile, self.comm)
         remove.display()
     
     def on_menuitem_stats_diff_activate(self, widget):
         """ Statistics/Differences... menu handler. """
         from diff import OliveDiff
-        diff = OliveDiff(self.gladefile, self.comm, self.dialog)
+        diff = OliveDiff(self.gladefile, self.comm)
         diff.display()
     
     def on_menuitem_stats_infos_activate(self, widget):
         """ Statistics/Informations... menu handler. """
         from info import OliveInfo
-        info = OliveInfo(self.gladefile, self.comm, self.dialog)
+        info = OliveInfo(self.gladefile, self.comm)
         info.display()
     
     def on_menuitem_stats_log_activate(self, widget):
         """ Statistics/Log... menu handler. """
         from log import OliveLog
-        log = OliveLog(self.gladefile, self.comm, self.dialog)
+        log = OliveLog(self.gladefile, self.comm)
         log.display()
     
     def on_menuitem_view_refresh_activate(self, widget):
@@ -345,8 +343,4 @@
         self.comm.pref.write()
         self.comm.window_main.destroy()
 
-    def not_implemented(self, widget):
-        """ Display a Not implemented error message. """
-        self.dialog.error_dialog(_('We feel sorry'),
-                                 _('This feature is not yet implemented.'))
 

=== modified file 'olive/menu.py'
--- olive/menu.py	2006-09-27 17:25:14 +0000
+++ olive/menu.py	2006-09-27 17:38:39 +0000
@@ -29,12 +29,13 @@
     sys.exit(1)
 
 import bzrlib.errors as errors
+from dialog import error_dialog
 
 from launch import launch
 
 class OliveMenu:
     """ This class is responsible for building the context menus. """
-    def __init__(self, gladefile, comm, dialog):
+    def __init__(self, gladefile, comm):
         # Load the UI file
         if sys.platform == 'win32':
             self.uifile = os.path.dirname(sys.executable) + "/share/olive/cmenu.ui"
@@ -52,7 +53,6 @@
         
         self.gladefile = gladefile
         self.comm = comm
-        self.dialog = dialog
         
         # Create the file list context menu
         self.ui = gtk.UIManager()
@@ -138,14 +138,14 @@
         filename = self.comm.get_selected_right()
             
         if filename is None:
-            self.dialog.error_dialog(_('No file was selected'),
+            error_dialog(_('No file was selected'),
                                      _('Please select a file from the list,\nor choose the other option.'))
             return
         
         try:
             bzrlib.add.smart_add([directory + '/' + filename])
         except errors.NotBranchError:
-            self.dialog.error_dialog(_('Directory is not a branch'),
+            error_dialog(_('Directory is not a branch'),
                                      _('You can perform this action only in a branch.'))
             return
         
@@ -158,7 +158,7 @@
         filename = self.comm.get_selected_right()
         
         if filename is None:
-            self.dialog.error_dialog(_('No file was selected'),
+            error_dialog(_('No file was selected'),
                                      _('Please select a file from the list,\nor choose the other option.'))
             return
         
@@ -167,11 +167,11 @@
             wt.remove(path)
 
         except errors.NotBranchError:
-            self.dialog.error_dialog(_('Directory is not a branch'),
+            error_dialog(_('Directory is not a branch'),
                                      _('You can perform this action only in a branch.'))
             return
         except errors.NotVersionedError:
-            self.dialog.error_dialog(_('File not versioned'),
+            error_dialog(_('File not versioned'),
                                      _('The selected file is not versioned.'))
             return
         except:
@@ -185,7 +185,7 @@
         filename = self.comm.get_selected_right()
         
         if filename is None:
-            self.dialog.error_dialog(_('No file was selected'),
+            error_dialog(_('No file was selected'),
                                      _('Please select a file from the list,\nor choose the other option.'))
             return
 
@@ -205,22 +205,22 @@
         """ Right context menu -> Commit """
         from commit import OliveCommit
         wt, path = WorkingTree.open_containing(self.comm.get_path())
-        commit = OliveCommit(self.gladefile, wt, path, self.dialog)
+        commit = OliveCommit(self.gladefile, wt, path)
         commit.display()
     
     def diff(self, action):
         """ Right context menu -> Diff """
         from diff import OliveDiff
-        diff = OliveDiff(self.gladefile, self.comm, self.dialog)
+        diff = OliveDiff(self.gladefile, self.comm)
         diff.display()
     
     def bookmark(self, action):
         """ Right context menu -> Bookmark """
         if self.comm.pref.add_bookmark(self.comm.get_path()):
-            self.dialog.info_dialog(_('Bookmark successfully added'),
+            info_dialog(_('Bookmark successfully added'),
                                     _('The current directory was bookmarked. You can reach\nit by selecting it from the left panel.'))
         else:
-            self.dialog.warning_dialog(_('Location already bookmarked'),
+            warning_dialog(_('Location already bookmarked'),
                                        _('The current directory is already bookmarked.\nSee the left panel for reference.'))
         
         self.comm.refresh_left()
@@ -230,7 +230,7 @@
         from bookmark import OliveBookmark
 
         if self.comm.get_selected_left() != None:
-            bookmark = OliveBookmark(self.gladefile, self.comm, self.dialog)
+            bookmark = OliveBookmark(self.gladefile, self.comm)
             bookmark.display()
 
     def remove_bookmark(self, action):
@@ -254,5 +254,5 @@
     def diff_all(self, action):
         """ Diff toolbutton -> All... """
         from diff import OliveDiff
-        diff = OliveDiff(self.gladefile, self.comm, self.dialog)
+        diff = OliveDiff(self.gladefile, self.comm)
         diff.display()

